==> mongodbcom-integration-broker-0.1.4.tgz: package/src/segment.js <==
import { querystring, getCookie } from './util'

function load (key) {
  var analytics = window.analytics = window.analytics || []; if (!analytics.initialize) {
    if (analytics.invoked)window.console && console.error && console.error('Segment snippet included twice.'); else {
      analytics.invoked = !0; analytics.methods = ['trackSubmit', 'trackClick', 'trackLink', 'trackForm', 'pageview', 'identify', 'reset', 'group', 'track', 'ready', 'alias', 'debug', 'page', 'once', 'off', 'on']; analytics.factory = function (t) { return function () { var e = Array.prototype.slice.call(arguments); e.unshift(t); analytics.push(e); return analytics } }; for (var t = 0; t < analytics.methods.length; t++) { var e = analytics.methods[t]; analytics[e] = analytics.factory(e) }analytics.load = function (t, e) { var n = document.createElement('script'); n.type = 'text/javascript'; n.async = !0; n.src = 'https://cdn.segment.com/analytics.js/v1/' + t + '/analytics.min.js'; var a = document.getElementsByTagName('script')[0]; a.parentNode.insertBefore(n, a); analytics._loadOptions = e }; analytics.SNIPPET_VERSION = '4.1.0'
      analytics.load(key)
    }
  }
}

function getContext () {
  const qs = querystring()
  const gaCookie = getCookie('_ga')

  const context = {
    'Google Analytics': {
      clientId: gaCookie ? gaCookie.split('.').slice(-2).join('.') : ''
    }
  }

  const campaign = {}

  if (qs.utm_campaign) campaign.name = qs.utm_campaign
  if (qs.utm_source) campaign.source = qs.utm_source
  if (qs.utm_medium) campaign.medium = qs.utm_medium
  if (qs.utm_term) campaign.term = qs.utm_term
  if (qs.utm_content) campaign.content = qs.utm_content
  if (qs.utm_keyword) campaign.keyword = qs.utm_keyword
  if (qs.utm_network) campaign.network = qs.utm_network
  if (qs.utm_creative) campaign.creative = qs.utm_creative
  if (qs.utm_matchtype) campaign.matchtype = qs.utm_matchtype
  if (qs.gclid) campaign.gclid = qs.gclid

  if (Object.keys(campaign).length > 0) {
    context.campaign = campaign
  }

  return context
}

function getSignupSource (path = window.location.pathname) {
  if (path.indexOf('/download-center') === 0) {
    return 'www download center'
  }

  if (path === '/cloud/atlas') {
    return 'www atlas overview'
  }

  if (path.indexOf('/cloud/atlas/lp') === 0) {
    return 'www atlas landing page'
  }

  if (path.indexOf('/dr') === 0) {
    return 'www download center postroll'
  }

  if (path === '/cloud/atlas/pricing') {
    return 'www atlas pricing'
  }

  if (path === '/cloud/atlas/signup') {
    return 'www atlas 2 step'
  }

  if (path === '/atlas-signup-from-mlab') {
    return 'mlab'
  }

  return 'www other'
}

function page (data = {}, context) {
  if (document.getElementById('atlas-form')) {
    Object.assign(data, { signup_source: getSignupSource() })
  }

  window.analytics.page(document.title, data, getContext())
}

function track (name, data) {
  window.analytics.track(name, data, getContext())
}

function identify (data) {
  window.analytics.identify(data, getContext())
}

function anonymousId () {
  try {
    return window.analytics.user().anonymousId()
  } catch (err) {
    return ''
  }
}

export const segment = {
  load,
  page,
  track,
  identify,
  anonymousId,
  getSignupSource
}

==> mongodbcom-integration-broker-0.1.9.tgz: package/src/segment.js <==
import { getCookie } from './util'
import { session } from './session'

function load (key) {
  var analytics = window.analytics = window.analytics || []; if (!analytics.initialize) {
    if (analytics.invoked)window.console && console.error && console.error('Segment snippet included twice.'); else {
      analytics.invoked = !0; analytics.methods = ['trackSubmit', 'trackClick', 'trackLink', 'trackForm', 'pageview', 'identify', 'reset', 'group', 'track', 'ready', 'alias', 'debug', 'page', 'once', 'off', 'on']; analytics.factory = function (t) { return function () { var e = Array.prototype.slice.call(arguments); e.unshift(t); analytics.push(e); return analytics } }; for (var t = 0; t < analytics.methods.length; t++) { var e = analytics.methods[t]; analytics[e] = analytics.factory(e) }analytics.load = function (t, e) { var n = document.createElement('script'); n.type = 'text/javascript'; n.async = !0; n.src = 'https://cdn.segment.com/analytics.js/v1/' + t + '/analytics.min.js'; var a = document.getElementsByTagName('script')[0]; a.parentNode.insertBefore(n, a); analytics._loadOptions = e }; analytics.SNIPPET_VERSION = '4.1.0'
      analytics.load(key)
    }
  }
}

function getContext () {
  const s = session.get()
  const gaCookie = getCookie('_ga')

  const context = {
    'Google Analytics': {
      clientId: gaCookie ? gaCookie.split('.').slice(-2).join('.') : ''
    }
  }

  const campaign = {}

  if (s.utm_campaign) campaign.name = s.utm_campaign
  if (s.utm_source) campaign.source = s.utm_source
  if (s.utm_medium) campaign.medium = s.utm_medium
  if (s.utm_term) campaign.term = s.utm_term
  if (s.utm_content) campaign.content = s.utm_content
  if (s.utm_keyword) campaign.keyword = s.utm_keyword
  if (s.utm_network) campaign.network = s.utm_network
  if (s.utm_creative) campaign.creative = s.utm_creative
  if (s.utm_matchtype) campaign.matchtype = s.utm_matchtype
  if (s.gclid) campaign.gclid = s.gclid

  if (Object.keys(campaign).length > 0) {
    context.campaign = campaign
  }

  return context
}

function getSignupSource (path = window.location.pathname) {
  if (path.indexOf('/download-center') === 0) {
    return 'www download center'
  }

  if (path === '/cloud/atlas') {
    return 'www atlas overview'
  }

  if (path.indexOf('/cloud/atlas/lp') === 0) {
    return 'www atlas landing page'
  }

  if (path.indexOf('/dr') === 0) {
    return 'www download center postroll'
  }

  if (path === '/cloud/atlas/pricing') {
    return 'www atlas pricing'
  }

  if (path === '/cloud/atlas/signup') {
    return 'www atlas 2 step'
  }

  if (path === '/atlas-signup-from-mlab') {
    return 'mlab'
  }

  return 'www other'
}

function page (data = {}, context) {
  if (document.getElementById('atlas-form')) {
    Object.assign(data, { signup_source: getSignupSource() })
  }

  window.analytics.page(document.title, data, getContext())
}

function track (name, data) {
  window.analytics.track(name, data, getContext())
}

function identify (data) {
  window.analytics.identify(data, getContext())
}

function anonymousId () {
  try {
    return window.analytics.user().anonymousId()
  } catch (err) {
    return ''
  }
}

export const segment = {
  load,
  page,
  track,
  identify,
  anonymousId,
  getSignupSource
}
